<?php //phpcs:ignore WordPress.Files.FileName.InvalidClassFileName
/**
 * Admin class
 *
 * @author  YITH <plugins@yithemes.com>
 * @package YITH WooCommerce EU Energy Label Premium
 * @version 1.0.0
 */

if ( ! defined( 'YITH_WCEUE' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'YITH_WCEUE_Admin_Premium' ) ) {
	/**
	 * Admin class.
	 * The class manage all the Admin behaviors.
	 *
	 * @since    1.0.0
	 */
	class YITH_WCEUE_Admin_Premium extends YITH_WCEUE_Admin {

		/**
		 * Single instance of the class
		 *
		 * @var YITH_WCEUE_Admin_Premium
		 * @since 1.0.0
		 */
		protected static $instance;

		/**
		 * Constructor
		 *
		 * @access public
		 * @since  1.0.0
		 */
		protected function __construct() {
			parent::__construct();

			add_filter( 'yith_wceue_settings_admin_tabs', array( $this, 'set_premium_tabs' ) );
			add_filter( 'yith_wceue_panel_settings_options', array( $this, 'add_options_in_settings_tab' ) );

			add_action( 'woocommerce_product_bulk_edit_end', array( $this, 'print_fields_in_bulk_edit' ) );
			add_action( 'woocommerce_product_bulk_edit_save', array( $this, 'save_bulk_edit' ), 10, 2 );

			add_action( 'manage_edit-product_columns', array( $this, 'add_custom_column' ), 10, 2 );
			add_action( 'manage_product_posts_custom_column', array( $this, 'render_custom_column' ), 10, 2 );

			add_filter( 'default_hidden_columns', array( $this, 'hide_custom_colum_by_default' ) );

		}

		/**
		 *  Modify Tabs in Best Sellers Settings Panel
		 *
		 * @param array $tabs Admin tabs.
		 * @return array
		 */
		public function set_premium_tabs( $tabs ) {
			unset( $tabs['premium'] );

			return $tabs;
		}

		/**
		 * Add premium options in Settings Tab
		 *
		 * @access public
		 * @since  1.0.0
		 * @param mixed $settings Options settings.
		 */
		public function add_options_in_settings_tab( $settings ) {
			$premium_settings = array(
				'link-options'     => array(
					'title' => __( 'Label Linking Options', 'yith-woocommerce-eu-energy-label' ),
					'type'  => 'title',
					'desc'  => '',
					'id'    => 'yith-wceue-link-options',
				),
				'link-to'          => array(
					'name'    => __( 'Energy label links to', 'yith-woocommerce-eu-energy-label' ),
					'type'    => 'select',
					'desc'    => __( 'Select what you want to link', 'yith-woocommerce-eu-energy-label' ),
					'id'      => 'yith-wceue-link-to',
					'options' => array(
						'none'       => __( 'Nothing', 'yith-woocommerce-eu-energy-label' ),
						'same_el'    => __( 'All products with the same energy label', 'yith-woocommerce-eu-energy-label' ),
						'custom_url' => __( 'Custom URL', 'yith-woocommerce-eu-energy-label' ),
					),
					'default' => 'none',
				),
				'link-custom-url'  => array(
					'name'    => __( 'Custom URL', 'yith-woocommerce-eu-energy-label' ),
					'type'    => 'text',
					'desc'    => __( 'Insert the custom URL', 'yith-woocommerce-eu-energy-label' ),
					'id'      => 'yith-wceue-link-custom-url',
					'default' => '',
				),
				'link-options-end' => array(
					'type' => 'sectionend',
					'id'   => 'yith-wceue-link-options',
				),
			);

			$settings['settings'] = array_merge( $settings['settings'], $premium_settings );

			return $settings;
		}

		/**
		 * Add panel for EU Energy Label Tab [in product wc-metabox]
		 *
		 * @access public
		 * @since  1.0.0
		 */
		public function add_product_data_panels() {
			global $post;
			$meta         = get_post_meta( $post->ID, '_yith_wceue_eu_meta', true );
			$energy_label = get_post_meta( $post->ID, '_yith_wceue_eu_energy_label', true );

			$meta_2021         = get_post_meta( $post->ID, '_yith_wceue_eu_meta_2021', true );
			$energy_label_2021 = get_post_meta( $post->ID, '_yith_wceue_eu_energy_label_2021', true );

			$default = array(
				'energy_label' => $energy_label,
				'show_tooltip' => 'off',
				'custom_image' => '',
			);

			$default_2021 = array(
				'energy_label' => $energy_label_2021,
				'show_tooltip' => 'off',
				'custom_image' => '',
			);

			$meta = wp_parse_args( $meta, $default );

			$meta_2021 = wp_parse_args( $meta_2021, $default_2021 );

			wc_get_template( '/admin/eu_energy_panel.php', $meta, YITH_WCEUE_TEMPLATE_PATH, YITH_WCEUE_TEMPLATE_PATH );

			wc_get_template( '/admin/eu_energy_panel_2021.php', $meta_2021, YITH_WCEUE_TEMPLATE_PATH, YITH_WCEUE_TEMPLATE_PATH );
		}

		/**
		 * Add a panel under YITH Plugins tab
		 *
		 * @return   void
		 * @since    1.0
		 * @use      /Yit_Plugin_Panel class
		 * @see      plugin-fw/lib/yit-plugin-panel.php
		 */
		public function register_panel() {
			parent::register_panel();
			add_action( 'woocommerce_admin_field_yith_wceue_upload', array( $this->panel, 'yit_upload' ), 10, 1 );
		}

		/**
		 * Enqueue backend scripts and styles
		 */
		public function admin_enqueue_scripts() {
			$suffix    = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
			$screen    = function_exists( 'get_current_screen' ) ? get_current_screen() : false;
			$screen_id = ! ! $screen ? $screen->id : false;

			wp_enqueue_style( 'yith_wceue_admin_style', YITH_WCEUE_ASSETS_URL . '/css/admin.css', array(), YITH_WCEUE_VERSION );

			if ( 'product' === $screen_id ) {
				wp_enqueue_script( 'yith_wceue_admin_product_js', YITH_WCEUE_ASSETS_URL . "/js/admin_product{$suffix}.js", array( 'jquery' ), YITH_WCEUE_VERSION, true );
				wp_localize_script(
					'yith_wceue_admin_product_js',
					'yith_lang',
					array(
						'choose_image' => __( 'Choose Image', 'yith-woocommerce-eu-energy-label' ),
					)
				);
			}

			$is_panel = strpos( $screen_id, '_page_yith_wceue_panel' ) > - 1;
			if ( $is_panel ) {
				wp_enqueue_script( 'yith_wceue_admin_settings_js', YITH_WCEUE_ASSETS_URL . "/js/admin_settings{$suffix}.js", array( 'jquery' ), YITH_WCEUE_VERSION, true );
			}

		}


		/**
		 * Print fields in bulk edit
		 *
		 */
		public function print_fields_in_bulk_edit() {
			static $print_nonce = true;
			if ( $print_nonce ) {
				$print_nonce = false;
				wp_nonce_field( YITH_WCEUE_INIT, 'bulk_eu_energy_edit_nonce' );
			}

			?>
			<label>
				<span class="title"><?php esc_html_e( 'EU Energy Label', 'yith-woocommerce-eu-energy-label' ); ?></span>
				<span class="input-text-wrap">
					<select name="yith_wceue_energy_label_id">
						<option value="" selected><?php esc_html_e( '— No Change —', 'yith-woocommerce-eu-energy-label' ); ?></option>
						<option value="0"><?php esc_html_e( 'None', 'yith-woocommerce-eu-energy-label' ); ?></option>
						<?php
						foreach ( yith_wceue_get_energy_label_array() as $id => $label ) {
                            $id = esc_html( $id );
                            $label = esc_html( $label );
							echo "<option value='{$id}'>{$label}</option>";
						}
						?>
					</select>
			</span>
			</label>

			<label>
				<span class="title">
				<?php esc_html_e( 'EU Energy Label (New 2021)', 'yith-woocommerce-eu-energy-label' ); ?></span>
				<span class="input-text-wrap">
					<select name="yith_wceue_energy_label_id_2021">
						<option value="" selected><?php esc_html_e( '— No Change —', 'yith-woocommerce-eu-energy-label' ); ?></option>
						<option value="0"><?php esc_html_e( 'None', 'yith-woocommerce-eu-energy-label' ); ?></option>
						<?php
						foreach ( yith_wceue_get_energy_label_array( 'new' ) as $id => $label ) {
							echo wp_kses_post( "<option value='{$id}'>{$label}</option>" );
						}
						?>
					</select>
			</span>
			</label>
			<?php
		}

		/**
		 * Save charts for bulk edit [AJAX]
		 *
		 * @param WC_Product $product Product object.
		 *
		 */
		public function save_bulk_edit( $product ) {
			if ( isset( $_REQUEST['yith_wceue_energy_label_id'] ) && '' !== $_REQUEST['yith_wceue_energy_label_id'] ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				$label_id = absint( $_REQUEST['yith_wceue_energy_label_id'] ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				if ( ! $label_id ) {
					$product->delete_meta_data( '_yith_wceue_eu_energy_label' );
				} else {
					$product->update_meta_data( '_yith_wceue_eu_energy_label', $label_id );
				}
				$product->save_meta_data();
			}
			if ( isset( $_REQUEST['yith_wceue_energy_label_id_2021'] ) && '' !== $_REQUEST['yith_wceue_energy_label_id_2021'] ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				$label_id = absint( $_REQUEST['yith_wceue_energy_label_id_2021'] ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				if ( ! $label_id ) {
					$product->delete_meta_data( '_yith_wceue_eu_energy_label_2021' );
				} else {
					$product->update_meta_data( '_yith_wceue_eu_energy_label_2021', $label_id );
				}
				$product->save_meta_data();
			}
		}

		/**
		 * Add custom columns "Energy Label" to products list
		 *
		 * @param [type] $columns Columns.
		 *
		 * @return array
		 */
		public function add_custom_column( $columns ) {
			$new_column = array( 'yith_eu_energy_label' => __( 'EU Energy Label', 'yith-woocommerce-eu-energy-label' ) );
			$columns    = array_merge( $new_column, $columns );
			return $columns;
		}

		/**
		 * Undocumented function
		 *
		 * @param [type] $column Column content.
		 * @param [type] $postid Post ID.
		 * @return void
		 */
		public function render_custom_column( $column, $postid ) {
			$product = wc_get_product( $postid );
			if ( 'yith_eu_energy_label' === $column ) {
				$label = yith_wceue_get_energy_label_for_product( 'energy_label', $product );
				if ( ! empty( $label ) ) {
					echo wp_kses_post( $this->get_icon( $product, $label ) );
				} else {
					echo esc_html( '-' );
				}
			}
		}

		/**
		 * Get Icon to show EU Energy Label in Products list
		 *
		 * @param [type] $product Product object.
		 * @param [type] $label   Label.
		 * @return string
		 */
		public function get_icon( $product, $label ) {
			$src = YITH_WCEUE_ASSETS_URL . '/icons/' . yith_wceue_get_version( $product ) . '/' . $label;
			return '<img src="' . $src . '.svg">';
		}


		/**
		 * Get energy label HTML
		 *
		 * @param WC_Product $product Product object.
		 * @return string
		 */
		public function get_energy_label_html( $product ) {

			$meta         = yith_wceue_get_energy_label_for_product( 'meta', $product );
			$energy_label = yith_wceue_get_energy_label_for_product( 'energy_label', $product );

			$html = '';

			$version = yith_wceue_get_version( $product );

			if ( $energy_label ) {
				$t_args = array(
					'class'        => 'yith-wceue-eu-energy-label-mini ' . $version,
					'energy_label' => $energy_label,
					'product_id'   => $product->get_id(),
					'meta'         => $meta,
					'version'      => $version,
				);
				ob_start();
				wc_get_template( '/energy_label.php', $t_args, '', YITH_WCEUE_TEMPLATE_PATH );
				$html = ob_get_clean();
			}

			return $html;
		}

		/**
		 * Hide custom column by default.
		 *
		 * @param array $hidden Hidden columns.
		 *
		 * @return array
		 */
		public function hide_custom_colum_by_default( $hidden ) {
			if ( ! in_array( 'yith_eu_energy_label', $hidden, true ) ) {
				$hidden[] = 'yith_eu_energy_label';
			}
			return $hidden;
		}


	}
}

/**
 * Unique access to instance of YITH_WCEUE_Admin class
 *
 * @return \YITH_WCEUE_Admin_Premium
 * @deprecated since 1.1.0 use YITH_WCEUE_Admin() instead
 * @since      1.0.0
 */
function YITH_WCEUE_Admin_Premium() { //phpcs:ignore WordPress.NamingConventions.ValidFunctionName.FunctionNameInvalid
	return YITH_WCEUE_Admin();
}
