<?php //phpcs:ignore WordPress.Files.FileName.InvalidClassFileName
/**
 * Main class
 *
 * @author  YITH <plugins@yithemes.com>
 * @package YITH WooCommerce EU Energy Label
 * @version 1.0.0
 */


if ( ! defined( 'YITH_WCEUE' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'YITH_WCEUE' ) ) {
	/**
	 * YITH WooCommerce EU Energy Label
	 *
	 * @since 1.0.0
	 */
	class YITH_WCEUE {

		/**
		 * Single instance of the class
		 *
		 * @var YITH_WCEUE
		 * @since 1.0.0
		 */
		private static $instance;

		/**
		 * Returns single instance of the class
		 *
		 * @return YITH_WCEUE
		 * @since 1.0.0
		 */
		public static function get_instance() {
			return ! is_null( self::$instance ) ? self::$instance : self::$instance = new self();
		}

		/**
		 * Constructor
		 *
		 * @since 1.0.0
		 */
		private function __construct() {

			// Load Plugin Framework.
			add_action( 'plugins_loaded', array( $this, 'plugin_fw_loader' ), 15 );

			if ( is_admin() ) {
				YITH_WCEUE_Admin();
			} else {
				YITH_WCEUE_Frontend();
			}

			add_action( 'before_woocommerce_init', array( $this, 'declare_wc_features_support' ) );

			// register plugin to licence/update system.
			add_action( 'wp_loaded', array( $this, 'register_plugin_for_activation' ), 99 );
			add_action( 'admin_init', array( $this, 'register_plugin_for_updates' ) );
		}

		/**
		 * Load Plugin Framework
		 *
		 * @since  1.0
		 * @access public
		 * @return void
		 */
		public function plugin_fw_loader() {
			if ( ! defined( 'YIT_CORE_PLUGIN' ) ) {
				global $plugin_fw_data;
				if ( ! empty( $plugin_fw_data ) ) {
					$plugin_fw_file = array_shift( $plugin_fw_data );
					require_once $plugin_fw_file;
				}
			}
		}

		/**
		 * Register plugins for activation tab
		 *
		 * @return void
		 * @since 1.1.19
		 */
		public function register_plugin_for_activation() {
			if ( function_exists( 'YIT_Plugin_Licence' ) ) {
				YIT_Plugin_Licence()->register( YITH_WCEUE_INIT, YITH_WCEUE_SECRET_KEY, YITH_WCEUE_SLUG );
			}
		}

		/**
		 * Register plugins for update tab
		 *
		 * @return void
		 * @since 1.1.19
		 */
		public function register_plugin_for_updates() {
			if ( function_exists( 'YIT_Upgrade' ) ) {
				YIT_Upgrade()->register( YITH_WCEUE_SLUG, YITH_WCEUE_INIT );
			}
		}

		/**
 		 * Declare support for WooCommerce features.
 		 */
		public function declare_wc_features_support() {
			if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', YITH_WCEUE_INIT, true );
			}
		}
	}
}

/**
 * Unique access to instance of YITH_WCEUE class
 *
 * @return YITH_WCEUE
 * @since 1.0.0
 */
function YITH_WCEUE() { //phpcs:ignore WordPress.NamingConventions.ValidFunctionName.FunctionNameInvalid
	return YITH_WCEUE::get_instance();
}
