<?php
/**
 * Functions file
 *
 * @package YITH\EUEnergyLabel\Includes
 */

if ( ! function_exists( 'yith_wceue_get_energy_label_array' ) ) {
	/**
	 * Get the energy label array
	 *
	 * @param string $version Version.
	 *
	 * @return array
	 */
	function yith_wceue_get_energy_label_array( $version = 'default' ) {

		if ( 'new' === $version ) {
			$energy_label_array = array(
				1 => 'A',
				2 => 'B',
				3 => 'C',
				4 => 'D',
				5 => 'E',
				6 => 'F',
				7 => 'G',
			);
		} else {
			$energy_label_array = array(
				1  => 'A+++',
				2  => 'A++',
				3  => 'A+',
				4  => 'A',
				5  => 'B',
				6  => 'C',
				7  => 'D',
				8  => 'E',
				9  => 'F',
				10 => 'G',
			);
		}

		/**
		 * APPLY_FILTERS: yith_wceue_get_energy_label_array
		 *
		 * Filters the energy labels to be used.
		 *
		 * @param array $energy_label_array Energy labels.
		 *
		 * @return array
		 */
		return apply_filters( 'yith_wceue_get_energy_label_array', $energy_label_array );
	}
}


if ( ! function_exists( 'yith_wceue_get_energy_label_meta_for_product' ) ) {
	/**
	 * Get the energy label for the specific product
	 *
	 * @param string     $field Field.
	 * @param WC_Product $product Product object.
	 *
	 * @return string
	 */
	function yith_wceue_get_energy_label_for_product( $field, $product ) {

		$value = '';

        if ( $product instanceof WC_Product ) {

            $version = yith_wceue_get_version( $product );
			switch ( $field ) {
				case 'energy_label':
					$value = 'new' === $version ? $product->get_meta( '_yith_wceue_eu_energy_label_2021', true ) : $product->get_meta( '_yith_wceue_eu_energy_label', true );
					break;

				case 'meta':
					$value = 'new' === $version ? $product->get_meta( '_yith_wceue_eu_meta_2021', true ) : $product->get_meta( '_yith_wceue_eu_meta', true );
					break;

				default:
					break;

			}
		}

		return $value;
	}
}


if ( ! function_exists( 'yith_wceue_get_version' ) ) {
	/**
	 * Get the version.
	 *
	 * @param WC_Product $product Product object.
	 *
	 * @return string
	 */
	function yith_wceue_get_version( $product ) {

		if ( $product instanceof WC_Product ) {
			$label_2021 = $product->get_meta( '_yith_wceue_eu_energy_label_2021', true );
			return empty( $label_2021 ) ? 'old' : 'new';
		} else {
			return 'old';
		}
	}
}
